package cli;

import java.io.File;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.Date;
import java.text.DateFormat;

/**
 * An abstract base class for a command-line applications that runs a numeric computation
 * and writes its output to a CSV file.
 */
public abstract class CLIAnalyzer {

    /**
     * The name of the directory to write the output file to. 
     */
    public final static String outputDir = "data-out/";

    /**
     * Write the output data to a CSV file. The data is given as a two-dimensional 
     * array of floating point numbers (indexed by row and column).
     * 
     * @param name The name of the output file, inside the directory given {@link #outputDir}
     * @param header A header line to be written as comment at the begining of the csv file
     * @param data the output data as 2d array of floating point numbers
     */
    public static void writeDatafile(String name, String header, double[][] data) {

        try {
            File outfile = new File(outputDir + name + ".csv");
            PrintWriter pw = new PrintWriter(outfile);

            pw.println("# " + header);
            pw.println("# Generated: "
                    + DateFormat.getDateTimeInstance().format(new Date()));

            int cols = data[0].length;

            for (int row = 0; row < data.length; row++) {
                String line = "";
                for (int col = 0; col < cols; col++) {
                    line += Double.toString(data[row][col]);
                    if (col < cols - 1) {
                        line += " ";
                    }
                }
                pw.println(line);
            }
            pw.close();

        } catch (IOException e) {
            System.err.println("I/O problem while writing to output file");
            e.printStackTrace(System.err);
        }
    }

}
