package cli;

import kernels.EnergyDensityKernel;
import models.*;

import org.apache.commons.math3.linear.RealVector;

/**
 * (For Fig 1) Computes the lowest eigenvector of the smeared energy density, 
 * for the Ising model and the sinh-Gordon model (coupling \(B=1\)).
 * 
 *  Takes two command line arguments: the number of discretization steps, \(N\), and the cutoff radius, \(R\).
 */
public class EigenvectorAnalyzer extends CLIAnalyzer {   
    
    public static void main(String[] args) {
        int N = Integer.parseInt(args[0]);
        double R = Double.parseDouble(args[1]);
        
        String header = "Ising and sinh-Gordon models, Energy density lowest eigenvector, N="+N+", R="+R;
        System.out.println(header);
        
        double[][] res = new double[N][3];

        IntegrableModel model;
        EnergyDensityKernel k;
        
        model = new IsingModel();
        k = new EnergyDensityKernel(model, 1.0, 0.0, 0, 0.1);
        RealVector isingV = k.findLowestEigenvector(N, R);
        
        model = new SinhGordonModel(1.0);
        k = new EnergyDensityKernel(model, 1.0, 0.0, 0, 0.1);
        RealVector sinhV = k.findLowestEigenvector(N, R);
        
        // amplitude of the orthonormal step functions 
        double amplitude = Math.pow(2*R/N, -0.5);
        for (int i = 0; i < N; i++) {
        	res[i][0] = -R+(2*R/N)*(i+0.5);
            res[i][1] = isingV.getEntry(i) * amplitude;
            res[i][2] = sinhV.getEntry(i) * amplitude;;
        }
        
        writeDatafile("Eigenvector", header, res);
    }
}
