package cli;

import kernels.EnergyDensityKernel;
import models.*;

/**
 * (For Fig 3a) Computes the lowest eigenvalue of the smeared energy density, 
 * for a model with S-matrix consisting of \(n\) sinh-Gordon factors (\(B=1\)),
 * where \(n\) is varied over a certain range.
 * 
 * Takes three command line arguments: the number \(N\) of discretization steps,
 * the rapidity cutoff \(R\), and the maximum number of S-matrix factors. 
 * (\(n\) is varied from 1 to this value.) 
 */
public class MultipleCouplingsAnalyzer extends CLIAnalyzer {

    private static double lowestEv(IntegrableModel model, int coshPower, int n,
            double cutoff) {
        EnergyDensityKernel k = new EnergyDensityKernel(model, 1.0, 0.0,
                coshPower, 0.1);
        double ev = k.findLowestEigenvalue(n, cutoff);
        return ev;
    }

    public static void main(String[] args) {
        int N = Integer.parseInt(args[0]);
        double R = Double.parseDouble(args[1]);
        int couplingsMax = Integer.parseInt(args[2]);

        String header = "Product model by number of factors, N=" + N + ", R="
                + R + ", up to " + couplingsMax + " factors at same coupling 1";
        System.out.println(header);

        double[][] res = new double[couplingsMax][2];

        for (int factors = 1; factors <= couplingsMax; factors++) {

            Object[] b = new Object[factors];
            for (int i = 0; i < factors; i++) {
                b[i] = new Double(1.0);
            }
            IntegrableModel model = new ProductModel(b);

            res[factors - 1][0] = factors;
            res[factors - 1][1] = lowestEv(model, factors / 2, N, R);
        }

        writeDatafile("MultipleCouplings", header, res);

    }
}
