package cli;

import kernels.EnergyDensityKernel;

import models.*;


/**
 * (For Fig 2) Computes the lowest eigenvalue of the smeared energy density, 
 * for the sinh-Gordon and the generalised Ising model, 
 * with coupling \(B\) varying from \(0\) to \(2\).
 * 
 * Takes three command line arguments: the number \(N\) of discretization steps,
 * the rapidity cutoff \(R\), and the number of steps in the coupling constant.
 * 
 */
public class SinhCouplingAnalyzer extends CLIAnalyzer {   

    public static void main(String[] args) {
        int N = Integer.parseInt(args[0]);
        double R = Double.parseDouble(args[1]);
        int couplingN = Integer.parseInt(args[2]);
        
        String header = "Sinh-Gordon and sinh-Ising lowest eigenvalues, N="+N+", R="+R + " coupling steps: " + couplingN;
        System.out.println(header);
        
        double[][] res = new double[couplingN][3];
        
        for (int i = 0; i < couplingN; i++) {
            double b = 2.0 / (couplingN - 1) * i;
            IntegrableModel m;
            EnergyDensityKernel k;

            res[i][0] = b;

            m = new SinhGordonModel(b);
            k = new EnergyDensityKernel(m, 1.0, 0.0, 0, 0.1);
            res[i][1] = k.findLowestEigenvalue(N, R);

            m = new SinhIsingModel(b);
            k = new EnergyDensityKernel(m, 1.0, 0.0, 1, 0.1);
            res[i][2] = k.findLowestEigenvalue(N, R);
        }

        writeDatafile("SinhCoupling", header, res);
    }
}
