package kernels;

import static org.junit.Assert.*;

import models.FreeModel;
import models.IsingModel;

import org.junit.Test;


/**
 * Unit tests for the class {@link EnergyDensityKernel}.
 *
 */
public class EnergyDensityKernelTest {

	/**
	 * Test the value of the kernel at (0,0) against the known value in the free model. 
	 */
	@Test
	public void testKernelValue() {
		
		EnergyDensityKernel k = new EnergyDensityKernel(new FreeModel(), 1.0, 0.0, 0, 0.1);
		
		double val = k.kernelValue(0, 0);
		assertEquals(1.0/2.0/Math.PI, val, 1e-10);
	}
	
	/**
	 * Verify the lowest eigenvalue of the energy density in the Ising model,
	 * obtained independently with an Octave program for cutoff \(R=10\), with \(n=1000\) steps.
	 */
	@Test
	public void testIsingLowerEV() {
		
		EnergyDensityKernel k = new EnergyDensityKernel(new IsingModel(), 1.0, 0.0, 0, 0.1);
		double lowestEV = k.findSpectrum(1000, 10)[0];
		
		// Octave program was for mass 1 and didn't take factor 1/2 Pi into account 
		double octaveResult = -0.72944 / 2.0 / Math.PI;
		
		assertEquals("Checking Ising model against external result", octaveResult, lowestEV, 1e-3);
	}

}
