package kernels;

import org.junit.Test;
import static org.junit.Assert.*;


/**
 * Unit tests for the class {@link kernels.OneParticleKernel}.
 */
public class OneParticleKernelTest {
    
    /**
     * Tests finding the spectrum of a kernel
     * using a kernel approximation of the identity operator.
     */
    @Test
    public void testFindSpectrum() {
        
    	final double r = 20.0;
    	final int n = 10;
    	final double step = 2*r/n; 
    	
        OneParticleKernel unity = new OneParticleKernel() {
             public double kernelValue(double theta, double eta) {
                 if (Math.abs(theta-eta) < step/2) {
                     return 1.0/step;
                 } else {
                     return 0.0;
                 }
             }
        };        
        unity.disableEVCheck();
        
        double[] actual = unity.findSpectrum(n, r);
        double[] expected = new double[] {1, 1, 1, 1, 1, 1, 1, 1, 1, 1};
        assertArrayEquals("testing spectrum of identity", expected, actual, 1e-10);
        
    }


}
