package models;

/**
 * An integrable model of quantum field theory with one species of scalar particle.
 * 
 * The only property that we require in our current context
 * of the function \(F_\mathrm{min}\) on the line \(\mathbb{R} + i \pi\).  
 * This is represented by the (abstract) method <code>FminIpi</code>.   
 * 
 */
public abstract class IntegrableModel
{
	
    /**
     * Computes the value of \(F_\text{min}(\theta + i \pi)\) for given \(\theta\).
     * This is always a real number in our context.
     * 
     * @param theta the value of the real argument \(\theta\), see above
     * @return the value of \(F_\text{min}(\theta + i \pi)\)
     */
    public abstract double FminIpi(double theta);

}
