package models;

import org.apache.commons.math3.analysis.UnivariateFunction;

/**
 * The sinh-Gordon model with coupling \( 0 < B < 2 \). 
 * 
 * This model has a rather nontrivial minimal solution, given by an integral expression.
 * This class uses numerical integration in order to obtain values of \( F_\text{min} \).
 * The results are cached in order to speed up multiple evaluations.
 */
public class SinhGordonModel extends IntegrableModel
{
    private CachedFunction fminIpi;
        
    /**
     * Constructs a new sinh-Gordon model with given real coupling constant \( B \in (0,2) \) . 
     * @param b the coupling constant of the model  
     */
    public SinhGordonModel(final double b) {

    	UnivariateFunction fminI = new UnivariateFunction() {
            public double value(double x) {
                return SinhTools.sinhIntegral(x, b);
            }
        };
       
        fminIpi = new CachedFunction(fminI, 1e-14);
    }

    @Override
    public double FminIpi(double theta) {
        return fminIpi.value(Math.abs(theta));
    }
        
}
