package models;

/**
 * The "sinh-Ising model" is an amalgamation of the sinh-Gordon and the Ising models.
 * 
 * Its scattering function is <em>minus</em> the sinh-Gordon scattering function:
 * 
 * \[ S(\zeta) = - \frac{\sinh \zeta - i \sin B \pi/2 }{\sinh \zeta + i \sin B \pi/2 }. \]
 * 
 * 
 * Correspondingly, the minimal solution is a product of the sinh-Gordon
 * minimal solution and that of the Ising model, with an additional factor to cancel the double zero at \( \zeta=0 \).
 * Explicitly,
 * 
 * \[ F_\text{min}(\theta + i\pi) =  \frac{F_\text{min,sinh-Gordon}(\theta + i\pi)}{ \cosh (\theta/2) } . \]
 * 
 *  
 */
public class SinhIsingModel extends IntegrableModel
{
    private SinhGordonModel sg;
    
    public SinhIsingModel(final double b) {
        sg = new SinhGordonModel(b);
    }

    @Override
    public double FminIpi(double theta) {
        return sg.FminIpi(theta) / Math.cosh(theta/2.0);
    }
    
}
